==> mb-js-bridge-5.1.4.tgz: package/lib/providers/wechat.js <==
/**
 *
 * @author    Jerry Bendy
 * @since     2/26/2018
 */
/* global wx */

import loadScript from 'scriptjs'
import ajax from '../utils/ajax'
import checkAccess from '../utils/checkAccess'
import webCommon from '../utils/web-common'

var isWechatReady = false,  // 微信环境是否初始化完成
    isAccessible = true,   // 是否可访问 JS Bridge 资源
    callStack = [],   // 初始化完成前的调用均缓存至此
    wechatVersion = '-'   // 微信版本号

var bridgeMethods = {
    /**
     * 初始化
     */
    INIT: function() {
        if (!checkAccess()) {
            isAccessible = false;
        }

        // 从 UserAgent 中获取当前微信版本号
        var v = navigator.userAgent.match(/MicroMessenger\/([\d.]+)\s?/)
        if (v && v[1]) {
            wechatVersion = v[1]
        }

        // 加载微信 JS-sdk 文件
        loadScript('//res.wx.qq.com/open/js/jweixin-1.2.0.js', function() {
            // 微信配置
            ajax.get({
                url: getWechatDomain() + 'api/wechat/get-js-signature?url=' + encodeURIComponent(location.href),
                success: function(data) {
                    wx.config(data)

                    wx.ready(function() {
                        isWechatReady = true

                        // 隐藏所有非基础按钮
                        wx.hideAllNonBaseMenuItem();

                        wx.hideMenuItems({
                            menuList: [
                                "menuItem:share:appMessage",
                                "menuItem:share:timeline"
                            ]
                        })

                        // 执行保存在 stack 中的调用
                        while (callStack.length) {
                            var c = callStack.shift()
                            invoke.apply(null, c);
                        }
                    })

                    wx.error(function(res) {
                        console.error(res)
                    })
                }
            })
        })

        // 重写 prompt 方法
        window.prompt = function(msg, _default) {
            try {
                if (_default) {
                    _default = JSON.parse(_default)
                }
            } catch (e) {}

            invoke(msg, _default, false)
        }

        // 附加 CSS 内容
        setExtraCSS()
    },

    /**
     * 获取用户信息
     *
     * @returns {{}}
     */
    JS_BRIDGE_GET_USER: function() {
        var cookieData = webCommon.getCookieFields()

        return Object.assign({}, {
            appName: 'ciq3',
            appVersion: 'wechat',
            sysType: 'wechat',
            sysVersion: wechatVersion,
            deviceId: 'WECHAT',
            sessionId: '',
            lang: 'zh',
            domain: webCommon.getApiDomain()
        }, cookieData)
    },

    /**
     * 打开指定页面
     *
     * @param params
     */
    JS_BRIDGE_OPEN_PAGE: function(params) {
        var pageName = params.pageName,
            data = params.data || {}

        switch (pageName) {
            case 'WEB_PAGE':
                location.href = data.url
                break
        }
    },

    /**
     * 显示加载动画（不包含文本）
     */
    JS_BRIDGE_OPEN_LOADING: function() {
        var $loading = getLoadingDOM('__BRIDGE_LOADING')
        $loading.style.display = 'block'
    },

    /**
     * 隐藏加载动画
     */
    JS_BRIDGE_CLOSE_LOADING: function() {
        var $loading = getLoadingDOM('__BRIDGE_LOADING')
        $loading.style.display = 'none'
    },

    JS_BRIDGE_CLOSE_WINDOW: function() {
        wx.closeWindow();
    },

    JS_BRIDGE_UPLOAD_PIC: function(data) {
        var callback = data.callback,
            $loading = getLoadingDOM('__BRIDGE_UPLOAD_LOADING')

        // 选择图片
        wx.chooseImage({
            count: 1,
            sizeType: ['compressed'],
            success: function(res) {
                var localId = res.localIds[0];

                $loading.style.display = 'block';

                // 上传图片
                wx.uploadImage({
                    localId: localId, // 需要上传的图片的本地ID，由chooseImage接口获得
                    success: function (res) {
                        var serverId = res.serverId; // 返回图片的服务器端ID
                        console.log(res);

                        ajax.get({
                            url: getWechatDomain() + 'api/wechat/upload-image?media_id=' + serverId,
                            success: function(data) {
                                $loading.style.display = 'none'
                                if (data.status === 200) {
                                    callback(data.data.imgUrl)
                                } else {
                                    alert(data.message)
                                }
                            },
                            error: function() {
                                $loading.style.display = 'none'
                            }
                        })
                    },
                    fail: function() {
                        $loading.style.display = 'none'
                    }
                });
            }
        })
    },

    /**
     *
     * @param data
     * @returns {string}
     */
    JS_BRIDGE_SHOW_IMAGE: function(data) {
        var imageUrl = data.imageUrl,
            currentPos = data.currentPos

        if (typeof imageUrl === 'string') {
            imageUrl = [imageUrl];
        }

        wx.previewImage({
            urls: imageUrl,
            current: (typeof currentPos === 'number' ? imageUrl[currentPos] : currentPos) || ''
        })
    },

    JS_BRIDGE_SHARE: function(data) {
        wx.showMenuItems({
            menuList: [
                "menuItem:share:appMessage",
                "menuItem:share:timeline"
            ]
        });

        wx.onMenuShareTimeline({
            title: data.title,
            link: data.url,
            imgUrl: data.image,
            success: function() {}
        })

        wx.onMenuShareAppMessage({
            title: data.title,
            desc: data.desc,
            link: data.url,
            imgUrl: data.image,
            type: 'link',
            success: function() {}
        })
    }
}

function invoke(key, data) {
    if (typeof bridgeMethods[key] === 'function') {

        var methodsWithoutInit = [
            'INIT',
            'JS_BRIDGE_GET_USER',
            'JS_BRIDGE_SET_USER',
            'JS_BRIDGE_OPEN_PAGE',
            'JS_BRIDGE_OPEN_LOADING',
            'JS_BRIDGE_CLOSE_LOADING'
        ]

        if (!isAccessible) {
            return null;
        }

        if (!isWechatReady && methodsWithoutInit.indexOf(key) < 0) {
            callStack.push([
                key,
                data
            ])

            console.info('Wechat invoking is cached')
            return null;
        }

        return bridgeMethods[key](data)
    }

    return null;
}

function getWechatDomain() {
    return webCommon.getApiDomain().replace(/ciqapi/i, 'wechat');
}

function setExtraCSS() {
    var css = '@-webkit-keyframes __jsBridgeLoading {0% {-webkit-transform: rotate3d(0, 0, 1, 0deg);} 100% {-webkit-transform: rotate3d(0, 0, 1, 360deg);}}' +
        '@keyframes __jsBridgeLoading {0% {transform: rotate3d(0, 0, 1, 0deg);} 100% {transform: rotate3d(0, 0, 1, 360deg);}}' +
        '.__bridge-mask_transparent {margin: 0; padding: 0; position: fixed; z-index: 1000; top: 0; right: 0; left: 0; bottom: 0}' +
        '.__bridge-toast {margin: 0; padding: 0; position: fixed; z-index: 5000; width: 100px; height: 100px; top: 180px; left: 50%; margin-left: -3.8em; background: rgba(17, 17, 17, 0.7); text-align: center; border-radius: 5px; color: #FFFFFF;}' +
        '.__bridge-icon-loading {margin: 30px 0 0; padding: 0; width: 38px; height: 38px; vertical-align: baseline; display: inline-block; -webkit-animation: __jsBridgeLoading 1s steps(12, end) infinite; animation: __jsBridgeLoading 1s steps(12, end) infinite; background: transparent url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIxMjAiIGhlaWdodD0iMTIwIiB2aWV3Qm94PSIwIDAgMTAwIDEwMCI+PHBhdGggZmlsbD0ibm9uZSIgZD0iTTAgMGgxMDB2MTAwSDB6Ii8+PHJlY3Qgd2lkdGg9IjciIGhlaWdodD0iMjAiIHg9IjQ2LjUiIHk9IjQwIiBmaWxsPSIjRTlFOUU5IiByeD0iNSIgcnk9IjUiIHRyYW5zZm9ybT0idHJhbnNsYXRlKDAgLTMwKSIvPjxyZWN0IHdpZHRoPSI3IiBoZWlnaHQ9IjIwIiB4PSI0Ni41IiB5PSI0MCIgZmlsbD0iIzk4OTY5NyIgcng9IjUiIHJ5PSI1IiB0cmFuc2Zvcm09InJvdGF0ZSgzMCAxMDUuOTggNjUpIi8+PHJlY3Qgd2lkdGg9IjciIGhlaWdodD0iMjAiIHg9IjQ2LjUiIHk9IjQwIiBmaWxsPSIjOUI5OTlBIiByeD0iNSIgcnk9IjUiIHRyYW5zZm9ybT0icm90YXRlKDYwIDc1Ljk4IDY1KSIvPjxyZWN0IHdpZHRoPSI3IiBoZWlnaHQ9IjIwIiB4PSI0Ni41IiB5PSI0MCIgZmlsbD0iI0EzQTFBMiIgcng9IjUiIHJ5PSI1IiB0cmFuc2Zvcm09InJvdGF0ZSg5MCA2NSA2NSkiLz48cmVjdCB3aWR0aD0iNyIgaGVpZ2h0PSIyMCIgeD0iNDYuNSIgeT0iNDAiIGZpbGw9IiNBQkE5QUEiIHJ4PSI1IiByeT0iNSIgdHJhbnNmb3JtPSJyb3RhdGUoMTIwIDU4LjY2IDY1KSIvPjxyZWN0IHdpZHRoPSI3IiBoZWlnaHQ9IjIwIiB4PSI0Ni41IiB5PSI0MCIgZmlsbD0iI0IyQjJCMiIgcng9IjUiIHJ5PSI1IiB0cmFuc2Zvcm09InJvdGF0ZSgxNTAgNTQuMDIgNjUpIi8+PHJlY3Qgd2lkdGg9IjciIGhlaWdodD0iMjAiIHg9IjQ2LjUiIHk9IjQwIiBmaWxsPSIjQkFCOEI5IiByeD0iNSIgcnk9IjUiIHRyYW5zZm9ybT0icm90YXRlKDE4MCA1MCA2NSkiLz48cmVjdCB3aWR0aD0iNyIgaGVpZ2h0PSIyMCIgeD0iNDYuNSIgeT0iNDAiIGZpbGw9IiNDMkMwQzEiIHJ4PSI1IiByeT0iNSIgdHJhbnNmb3JtPSJyb3RhdGUoLTE1MCA0NS45OCA2NSkiLz48cmVjdCB3aWR0aD0iNyIgaGVpZ2h0PSIyMCIgeD0iNDYuNSIgeT0iNDAiIGZpbGw9IiNDQkNCQ0IiIHJ4PSI1IiByeT0iNSIgdHJhbnNmb3JtPSJyb3RhdGUoLTEyMCA0MS4zNCA2NSkiLz48cmVjdCB3aWR0aD0iNyIgaGVpZ2h0PSIyMCIgeD0iNDYuNSIgeT0iNDAiIGZpbGw9IiNEMkQyRDIiIHJ4PSI1IiByeT0iNSIgdHJhbnNmb3JtPSJyb3RhdGUoLTkwIDM1IDY1KSIvPjxyZWN0IHdpZHRoPSI3IiBoZWlnaHQ9IjIwIiB4PSI0Ni41IiB5PSI0MCIgZmlsbD0iI0RBREFEQSIgcng9IjUiIHJ5PSI1IiB0cmFuc2Zvcm09InJvdGF0ZSgtNjAgMjQuMDIgNjUpIi8+PHJlY3Qgd2lkdGg9IjciIGhlaWdodD0iMjAiIHg9IjQ2LjUiIHk9IjQwIiBmaWxsPSIjRTJFMkUyIiByeD0iNSIgcnk9IjUiIHRyYW5zZm9ybT0icm90YXRlKC0zMCAtNS45OCA2NSkiLz48L3N2Zz4=) no-repeat; background-size: 100%}' +
        ''
    var $style = document.createElement('style')
    $style.innerHTML = css

    document.head.appendChild($style)
}

function getLoadingDOM(id) {
    var $loading = document.getElementById(id)
    if ($loading) {
        return $loading
    }

    $loading = document.createElement('div');
    $loading.id = id
    $loading.style.display = 'none'

    $loading.innerHTML = '<div class="__bridge-mask_transparent"></div><div class="__bridge-toast"><i class="__bridge-icon-loading"></i></div>'
    document.body.appendChild($loading)
    return $loading
}

export default invoke

==> mb-js-bridge-5.3.32.tgz: package/lib/providers/wechat.js <==
/**
 *
 * @author    Jerry Bendy
 * @since     2/26/2018
 */
/* global wx */

import loadScript from 'scriptjs'
import ajax from '../utils/ajax'
import checkAccess from '../utils/checkAccess'
import webCommon from '../utils/web-common'
import callBridge from '../utils/callBridge'
import * as mixPanel from '../utils/mixpanel'
import { bridgeMethods as webBridgeMethods } from './web'

var isWechatReady = false,  // 微信环境是否初始化完成
    isAccessible = true,   // 是否可访问 JS Bridge 资源
    callStack = [],   // 初始化完成前的调用均缓存至此
    wechatVersion = '-'   // 微信版本号

var bridgeMethods = {
    /**
     * 初始化
     */
    INIT: function() {
        if (!checkAccess()) {
            isAccessible = false;
            return;
        }

        // 从 UserAgent 中获取当前微信版本号
        var v = navigator.userAgent.match(/MicroMessenger\/([\d.]+)\s?/)
        if (v && v[1]) {
            wechatVersion = v[1]
        }

        // 加载微信 JS-sdk 文件
        loadScript('//res.wx.qq.com/open/js/jweixin-1.2.0.js', function() {
            // 微信配置
            ajax.get({
                url: webCommon.getH5Domain() + 'api/wechat/get-js-signature?url=' + encodeURIComponent(location.href),
                success: function(data) {
                    wx.config(data)

                    wx.ready(function() {
                        isWechatReady = true

                        // 隐藏所有非基础按钮
                        wx.hideAllNonBaseMenuItem();

                        wx.hideMenuItems({
                            menuList: [
                                "menuItem:share:appMessage",
                                "menuItem:share:timeline"
                            ]
                        })

                        // 执行保存在 stack 中的调用
                        while (callStack.length) {
                            var c = callStack.shift()
                            invoke.apply(null, c);
                        }
                    })

                    wx.error(function(res) {
                        console.error(res)
                    })
                }
            })
        })

        // 重写 prompt 方法
        window.prompt = function(msg, _default) {
            try {
                if (_default) {
                    _default = JSON.parse(_default)
                }
            } catch (e) {}

            invoke(msg, _default, false)
        }

        // 初始化 MixPanel
        mixPanel.initMixPanel()

        // 在窗体的 load 事件中加载对 DOM 的修改，避免把 JS 脚本放在 head 标签中时 body 元素未加载的问题
        window.addEventListener('load', function() {
            // 附加 CSS 内容
            webCommon.setExtraCSS()

            // 当前页面未设置字体时，修改默认字体为无衬线字体
            if (!document.body.style.fontFamily) {
                document.body.style.fontFamily = '"Helvetica Neue", Helvetica, "PingFang SC", "Hiragino Sans GB", "Microsoft YaHei", 微软雅黑, Arial, sans-serif'
            }
        })
    },

    /**
     * 获取用户信息
     *
     * @returns {{}}
     */
    JS_BRIDGE_GET_USER: function() {
        var cookieData = webCommon.getCookieFields()

        return Object.assign({}, {
            appName: 'ciq3',
            appVersion: 'wechat',
            sysType: 'wechat',
            sysVersion: wechatVersion,
            deviceId: 'WECHAT',
            sessionId: '',
            lang: 'zh',
            domain: webCommon.getApiDomain()
        }, cookieData)
    },

    /**
     * 获取用户资料
     */
    JS_BRIDGE_GET_USER_INFO: function() {
        return webBridgeMethods.JS_BRIDGE_GET_USER_INFO()
    },

    /**
     * 打开指定页面
     *
     * @param params
     */
    JS_BRIDGE_OPEN_PAGE: function(params) {
        var pageName = params.pageName,
            h5Domain = webCommon.getH5Domain()

        switch (pageName) {
            // case 'COURSE':
            //     // 知识库
            // case 'COURSE_SET_DETAIL':
            //     // 课程集
                // location.href = h5Domain + 'api/functions/ciq-only'
                // break
            case 'TASK':
                location.href = h5Domain + 'api/task/list'
                break

            case 'TASK_DETAIL':
                location.href = h5Domain + 'api/task/detail?' + new URLSearchParams(params.data)
                break

            case 'COURSE_QUIZ':
                location.href = h5Domain + 'api/course/quiz-gate?courseId=' + params.data.courseId
                break

            case 'COURSE_PAGE':
                location.href = h5Domain + 'api/course/course-page-container?courseSetId=' + params.data.courseSetId + '&courseId=' + params.data.courseId
                break

            case 'ACHIEVEMENT':
                location.href = h5Domain + 'api/achievement'
                break

            default:
                webBridgeMethods.JS_BRIDGE_OPEN_PAGE(params)
        }
    },

    /**
     * 显示加载动画（不包含文本）
     */
    JS_BRIDGE_OPEN_LOADING: function() {
        webCommon.showLoading()
    },

    /**
     * 隐藏加载动画
     */
    JS_BRIDGE_CLOSE_LOADING: function() {
        webCommon.hideLoading()
    },

    JS_BRIDGE_CLOSE_WINDOW: function() {
        wx.closeWindow();
    },

    JS_BRIDGE_UPLOAD_PIC: function(data) {
        var callback = data.callback

        // 选择图片
        wx.chooseImage({
            count: 1,
            sizeType: ['compressed'],
            success: function(res) {
                var localId = res.localIds[0];

                webCommon.showLoading()

                // 上传图片
                wx.uploadImage({
                    localId: localId, // 需要上传的图片的本地ID，由chooseImage接口获得
                    success: function (res) {
                        var serverId = res.serverId; // 返回图片的服务器端ID

                        ajax.get({
                            url: webCommon.getH5Domain() + 'api/wechat/upload-image?media_id=' + serverId,
                            success: function(data) {
                                webCommon.hideLoading()
                                if (data.status === 200) {
                                    callback(data.data.imgUrl)
                                } else {
                                    alert(data.message)
                                }
                            },
                            error: function() {
                                webCommon.hideLoading()
                            }
                        })
                    },
                    fail: function() {
                        webCommon.hideLoading()
                    }
                });
            }
        })
    },

    /**
     *
     * @param data
     * @returns {string}
     */
    JS_BRIDGE_SHOW_IMAGE: function(data) {
        var imageUrl = data.imageUrl,
            currentPos = data.currentPos

        wx.previewImage({
            urls: imageUrl,
            current: imageUrl[currentPos]
        })
    },

    JS_BRIDGE_SHARE: function(data) {
        wx.showMenuItems({
            menuList: [
                "menuItem:share:appMessage",
                "menuItem:share:timeline"
            ]
        });

        wx.onMenuShareTimeline({
            title: data.title,
            link: data.url,
            imgUrl: data.image,
            success: function() {
                // TODO 添加分享成功回调
            }
        })

        wx.onMenuShareAppMessage({
            title: data.title,
            desc: data.desc,
            link: data.url,
            imgUrl: data.image,
            type: 'link',
            success: function() {}
        })
    },

    /**
     * 高级分享（处理方式同分享接口）
     * @param params
     */
    JS_BRIDGE_PLATFORM_SHARE: function(params) {
        this.JS_BRIDGE_SHARE(params)
    },

    /**
     * 重登录，当用户信息过期时使用
     */
    JS_BRIDGE_SESSION_INVALID: function() {
        webCommon.logout(function() {
            // 关闭窗口
            callBridge('CLOSE_WINDOW');
        });
    },

    /**
     * 事件记录（埋点）
     */
    JS_BRIDGE_EVENTS_STATISTIC: function(params) {
        mixPanel.trackEvent(params.eventName, params.properties)
    }
}

function invoke(key, data) {
    if (typeof bridgeMethods[key] === 'function') {

        var methodsWithoutInit = [
            'INIT',
            'JS_BRIDGE_GET_USER',
            'JS_BRIDGE_GET_USER_INFO',
            'JS_BRIDGE_SET_USER',
            'JS_BRIDGE_OPEN_PAGE',
            'JS_BRIDGE_OPEN_LOADING',
            'JS_BRIDGE_CLOSE_LOADING'
        ]

        if (!isAccessible) {
            return null;
        }

        if (!isWechatReady && methodsWithoutInit.indexOf(key) < 0) {
            callStack.push([
                key,
                data
            ])

            console.info('Wechat invoking is cached')
            return null;
        }

        return bridgeMethods[key](data)
    }

    return null;
}

export default invoke
